==> replacer-1.1.1%2B1.21.%282-4%29-Fabric-sources.jar: eva/replacer/mixin/client/MinecraftMixin.java <==
package eva.replacer.mixin.client;

import eva.replacer.mixin.client.access.BlockHitResultAccess;
import eva.replacer.mixin.client.access.MultiPlayerGameModeInvoker;
import eva.replacer.util.BuildInProgress;
import eva.replacer.util.RelPos;
import net.minecraft.class_1747;
import net.minecraft.class_2885;
import net.minecraft.class_310;
import net.minecraft.class_3965;
import net.minecraft.class_636;
import net.minecraft.class_638;
import net.minecraft.class_746;
import org.jetbrains.annotations.NotNull;
import org.spongepowered.asm.mixin.Mixin;
import org.spongepowered.asm.mixin.Shadow;
import org.spongepowered.asm.mixin.Unique;
import org.spongepowered.asm.mixin.injection.At;
import org.spongepowered.asm.mixin.injection.Inject;
import org.spongepowered.asm.mixin.injection.callback.CallbackInfo;

import static eva.replacer.config.RePlacerConfig.isCompatMode;
import static eva.replacer.config.RePlacerConfig.isServer;
import static eva.replacer.util.BuildInProgress.*;

@Mixin(class_310.class)
public abstract class MinecraftMixin {
    @Unique private int waiter;
    @Shadow @NotNull public class_746 player;
    @Shadow @NotNull public class_636 gameMode;

    @Inject(
            method = "tick",
            at = @At("HEAD")
    )
    private void placeAgain(CallbackInfo ci) {
        if (isCompatMode())
            if (rePlacing()) {
                if (!isServer() || isReadyForBlock())
                    if (player.method_5998(context().method_20287()).method_7909() instanceof class_1747 item) {
                        if (!BuildInProgress.isEmpty()) {
                            if (player.method_5998(context().method_20287()).method_7960()) {
                                if (waiter <= 0) {
                                    if (!isClear()) BuildInProgress.clear();
                                    rePlacing(false);
                                    return;
                                }
                                waiter--;
                                return;
                            }
                            waiter = 2;
                            RelPos pos = next();
                            if (player.method_56093(pos.pos(), player.method_55754() + 1)) {
                                class_3965 result = BuildInProgress.place(pos, null, context().method_8036(), item);
                                if (((BlockHitResultAccess)result).isMiss())
                                    player.method_37908().method_61271(RelPos.origin.pos(), item.method_7711());
                                else {
                                    ((MultiPlayerGameModeInvoker) gameMode).invokeStartPrediction((class_638) context().method_8045(), i -> new class_2885(context().method_20287(), result, i));
                                    setReadyForBlock(false);
                                }
                            }
                            return;
                        } else if (!isClear()) BuildInProgress.clear();
                        rePlacing(false);
                    }
            }
    }
}

==> replacer-1.2.0%2B1.21.%286-8%29-Fabric-sources.jar: eva/replacer/mixin/client/MinecraftMixin.java <==
package eva.replacer.mixin.client;

import eva.replacer.mixin.client.access.BlockHitResultAccess;
import eva.replacer.mixin.client.access.MultiPlayerGameModeInvoker;
import eva.replacer.util.BuildInProgress;
import eva.replacer.util.RelPos;
import net.fabricmc.api.EnvType;
import net.fabricmc.api.Environment;
import net.minecraft.class_1747;
import net.minecraft.class_2885;
import net.minecraft.class_310;
import net.minecraft.class_3965;
import net.minecraft.class_636;
import net.minecraft.class_746;
import org.jetbrains.annotations.NotNull;
import org.spongepowered.asm.mixin.Mixin;
import org.spongepowered.asm.mixin.Shadow;
import org.spongepowered.asm.mixin.Unique;
import org.spongepowered.asm.mixin.injection.At;
import org.spongepowered.asm.mixin.injection.Inject;
import org.spongepowered.asm.mixin.injection.callback.CallbackInfo;

import static eva.replacer.config.RePlacerConfig.isCompatMode;
import static eva.replacer.config.RePlacerConfig.isServer;
import static eva.replacer.util.BuildInProgress.*;

@Environment(EnvType.CLIENT)
@Mixin(class_310.class)
public abstract class MinecraftMixin {
    @Unique private int waiter;
    @Shadow @NotNull public class_746 player;
    @Shadow @NotNull public class_636 gameMode;

    @Inject(
            method = "tick",
            at = @At("HEAD")
    )
    private void placeAgain(CallbackInfo ci) {
        if (isCompatMode()) {
            if (rePlacing()) {
                if (!isServer() || isReadyForBlock()) {
                    if (player.method_5998(context().method_20287()).method_7909() instanceof class_1747 item) {
                        if (!BuildInProgress.isEmpty()) {
                            if (player.method_5998(context().method_20287()).method_7960()) {
                                waiter++;
                                return;
                            }
                            waiter = 0;
                            RelPos pos = next();
                            if (player.method_56093(pos.pos(), player.method_55754() + 1)) {
                                class_3965 result = BuildInProgress.place(pos, null, context().method_8036(), item);
                                if (((BlockHitResultAccess) result).isMiss())
                                    player.method_37908().method_8408(RelPos.origin.pos(), item.method_7711());
                                else {
                                    ((MultiPlayerGameModeInvoker) gameMode).invokeStartPrediction(class_310.method_1551().field_1687, i -> new class_2885(context().method_20287(), result, i));
                                    setReadyForBlock(false);
                                }
                            }
                            return;
                        } else if (!isClear()) BuildInProgress.clear();
                        rePlacing(false);
                    }
                } else {
                    if (waiter >= 5) {
                        if (!isClear()) BuildInProgress.clear();
                        rePlacing(false);
                        return;
                    }
                    waiter++;
                }
            }
        }
    }
}
